@@ -1,5 +1,7 @@
 from .articles import Articles
 from .clients import Clients
+from .tercers import Tercers
+from .repartidors import Repartidors
 from .comandes import Comandes
 from .pobles import Pobles
 from .provincies import Provincies
