@@ -19,6 +19,10 @@ class Articles:
         req = self._con.get(url=self._url_get_articles+'/'+str(p_article))
         return req.json()
 
+    def get_article_by_ean(self, p_ean13_article: str):
+        req = self._con.get(url=self._url_get_articles+'?ean13_article='+str(p_ean13_article))
+        return req.json()
+
     def get_article_atribut(self, p_article_id: int):
         tmp_atributs = self.get_articles_atributs(p_article_id)
         res = None
