@@ -39,11 +39,14 @@ class Wms:
 
     def get_tip_unitat_logistica_palet(self):
         tmp_url = Wms._url_tip_unitat_logistica_palet
-        llista = self._con.get(url=tmp_url)
+        result = self._con.get(url=tmp_url)
         res = None
+        llista = {}
+        if result is not None:
+            llista = result.json()
         if (llista is not None) and (len(llista) > 0):
             res = llista[0]
-        return res.json()
+        return res
 
     def get_unitats_logistiques_formats(self, p_tip_unitat_logistica_id: int):
         tmp_url = Wms._url_unitat_logistica_format.format(tip_unitat_logistica_id=p_tip_unitat_logistica_id)
